@@ -1,8 +1,6 @@
 from .integromat import Integromat
 from .darkknight import DarkKnight
 from .ftp import Ftp
-from .ftps import Ftps
-from .ftps_toucan import Ftps_toucan
 from .geolocator import GeoLocator
 from .git import Git
 from .gsheet import Gsheet
@@ -20,9 +18,11 @@ from .yahoo import Yahoo
 from airtable import Airtable
 from .zappier import Zappier
 from .ifttt import Ifttt
+import requests
 
-__version__ = "0.15.2"
+__version__ = "0.17.0"
 
+__github_repo = "jupyter-naas/drivers"
 darkknight = DarkKnight
 airtable = Airtable
 zappier = Zappier
@@ -30,8 +30,6 @@ integromat = Integromat
 ifttt = Ifttt
 yahoo = Yahoo
 ftp = Ftp
-ftps = Ftps
-ftps_toucan = Ftps_toucan
 git = Git
 geoLocator = GeoLocator
 gsheet = Gsheet
@@ -45,3 +43,17 @@ cityfalcon = Cityfalcon
 prediction = Prediction
 sentiment_analysis = SentimentAnalysis
 toucan = Toucan
+
+
+def version():
+    print(__version__)
+
+
+def get_last_version():
+    url = f"https://api.github.com/repos/{__github_repo}/tags"
+    response = requests.get(url, headers={"Accept": "application/vnd.github.v3+json"})
+    return response.json()[0]["name"]
+
+
+def up_to_date():
+    return get_last_version() == version()
