@@ -8,4 +8,4 @@ class Zappier:
             json=data,
         )
         r.raise_for_status()
-        r.json()
+        return r.json()
